import { ColumnRefNode, ExpectedLiteralNode, FromTableNode, NodeRange, SelectStatement } from '@joe-re/sql-parser';
import { CompletionItem } from 'vscode-languageserver-types';
import { Table, DbFunction } from '../database_libs/AbstractClient';
declare type Pos = {
    line: number;
    column: number;
};
export declare const ICONS: {
    KEYWORD: 1;
    COLUMN: 8;
    TABLE: 5;
    FUNCTION: 10;
    ALIAS: 6;
    UTILITY: 23;
};
export declare function makeTableAlias(tableName: string): string;
export declare function getRidOfAfterPosString(sql: string, pos: Pos): string;
export declare function getLastToken(sql: string): string;
export declare function makeTableName(table: Table): string;
export declare function isPosInLocation(location: NodeRange, pos: Pos): boolean;
export declare function toCompletionItemForFunction(f: DbFunction): CompletionItem;
export declare function toCompletionItemForAlias(alias: string): CompletionItem;
export declare function toCompletionItemForKeyword(name: string): CompletionItem;
export declare function createCandidatesForExpectedLiterals(nodes: ExpectedLiteralNode[]): CompletionItem[];
export declare function getAliasFromFromTableNode(node: FromTableNode): string;
/**
 * Test if the given table matches the fromNode.
 * @param fromNode
 * @param table
 * @returns
 */
export declare function isTableMatch(fromNode: FromTableNode, table: Table): boolean;
export declare function getColumnRefByPos(columns: ColumnRefNode[], pos: Pos): ColumnRefNode | undefined;
export declare function makeColumnName(alias: string, columnName: string): string;
export declare function createTablesFromFromNodes(fromNodes: FromTableNode[]): Table[];
export declare function findColumnAtPosition(ast: SelectStatement, pos: Pos): ColumnRefNode | null;
/**
 * Recursively pull out the FROM nodes (including sub-queries)
 * @param tableNodes
 * @returns
 */
export declare function getAllNestedFromNodes(tableNodes: FromTableNode[]): FromTableNode[];
/**
 * Finds the most deeply nested FROM node that have a range encompasing the position.
 * In cases such as SELECT * FROM T1 JOIN (SELECT * FROM (SELECT * FROM T2 <pos>))
 * We will get a list of nodes like this
 * SELECT * FROM T1
 * (SELECT * FROM
 *    (SELECT * FROM T2))
 * The idea is to reverse the list so that the most nested queries come first. Then
 * apply a filter to keep only the FROM nodes which encompass the position and take
 * the first one from that resulting list.
 * @param fromNodes
 * @param pos
 * @returns
 */
export declare function getNearestFromTableFromPos(fromNodes: FromTableNode[], pos: Pos): FromTableNode | null;
export {};
